#!/usr/bin/env python
# coding=utf-8
"""
@author: Jiawei Wu
@create time: 2019-12-06 23:16
@edit time: 2020-11-23 17:29
@FilePath: /vvlab/vvlab/agents/__init__.py
"""


from .DDPG_base import DDPGBase
from .DQN_base import DQNBase
from .Linear_base import LinearBase